(* ::Package:: *)

(*:Package Version: 2.05 *)

(*:Version History: -.-- (1998.07.12 : Dirichlet)
                    1.01 (2004.03.15 - 2006.06.16)
                    1.02 (2006.06.17 - 2006.06.18)
                    1.03 (2006.06.19 - 2006.07.07)
                    2.01 (2006.07.08 - 2008.09.14)
                    2.02 (2008.09.15 - 2011.04.30)
                    2.03 (2011.05.01 - 2014.08.14)
                    2.04 (2014.08.15 - 2015.03.11)
                    2.05 (2015.03.12 -     .  .  ) *)

(*:Copyright: Copyright 1998.7-2015.3, Souichiro Ikebe *)

(*:Author: Souichiro Ikebe *)

(*:Name: SpecialFunctions`Zeta` *)

(*:Title: Zeta *)

(*:Keywords: RiemannXi, DirichletChi, DirichletL, 
             PeriodicZetaF, HurwitzZeta, ZetaPrime, 
             StieltjesFGamma, SitaramachandraraoDelta, 
             BellExponentB, BellExponentB2, GlaisherRamanujanG, 
             GlaisherRamanujanG2, LandauHurwitzP, 
             RamanujanSiegelTheta, RamanujanSiegelZ, 
             FibonacciZeta, 
             RiemannPrimeR, RiemannPrimeRExp,
             RiemannExpIntegral, RiemannLogIntegral, 
             RiemannTermNonTrivialZero, 
             RiemannVonMangoldtPi *)

(*:Summary:
 
  This package implements the functions related zeta function, 
  Dirichlet series & Stieltjes function. 
  And incidental to, also implements of the Riemann's prime-
  counting function R(x) & Riemann-Von Mangoldt's formula. *)

(*****************************************************************************)






BeginPackage["SpecialFunctions`Zeta`",
"NumberTheory`Ramanujan`"]






RiemannXi::usage =
"RiemannXi[s] gives the Riemann's xi function.
 Xi[s]=s*(s-1)*Pi^(-s/2)*Gamma[s/2]*Zeta[s]."

DirichletChi::usage =
"DirichletChi[m,n] gives the Dirichlet's real
 primitive character Chi. m is Grundzahl at 
 m = ...-15,-11,-8,-7,-4,-3, 1, 5, 8,12,13,17,..."

DirichletL::usage =
"DirichletL[s,m] gives the Dirichlet's L-function
 of real primitive character Chi. m is Grundzahl at 
 m = ...-15,-11,-8,-7,-4,-3, 1, 5, 8,12,13,17,..."

PeriodicZetaF::usage =
"PeriodicZetaF[s,a] gives the periodic zeta F-function.
 F[s,a]=Sum[Exp[2 Pi I k a]/k^s,{k,1,Infinity}]."

HurwitzZeta::usage =
"HurwitzZeta[s,a] gives the Hurwitz zeta function the
 same Zeta[s,a]. But supported large argument more than 
 HurwitzZeta[s,a] or Mathematica in it."

ZetaPrime::usage =
 "ZetaPrime[d,s] gives the d-th derivative of Riemann's
  zeta function."

StieltjesFGamma::usage =
"StieltjesFGamma[s] gives the Stieltjes function."

SitaramachandraraoDelta::usage =
"SitaramachandraraoDelta[s] gives the Sitaramachandrarao function."

BellExponentB::usage =
"BellExponentB[s] gives the Bell function."

BellExponentB2::usage =
"BellExponentB2[s] gives the second Bell function."

GlaisherRamanujanG::usage =
"GlaisherRamanujanG[s] gives the Glaisher-Ramanujan function."

GlaisherRamanujanG2::usage =
"GlaisherRamanujanG2[s] gives the second Glaisher-Ramanujan function."

LandauHurwitzP::usage =
"LandauHurwitzP[z] gives the Landau-Hurwitz function.
 It's analogy of the Riemann's zeta function at 
 Sum[1/Prime[n]^z,{n,1,Infinity}]."

RamanujanSiegelTheta::usage =
"RamanujanSiegelTheta[t] is analogous to
 RiemannSiegelTheta[t] in the theory of the Riemann zeta 
 function. In particular, Exp[I RamanujanSiegelTheta[t]]*
 RamanujanTauDirichletSeries[6 + I t] is 
 RamanujanSiegelZ[t] and is a real valued function 
 if t is real."

RamanujanSiegelZ::usage =
"RamanujanSiegelZ[t] evaluates the function
 Exp[I RamanujanSiegelTheta[t]]*
 RamanujanTauDirichletSeries[6 + I t].
 RamanujanSiegelZ[t] is analogous to RiemannSiegelZ[t] 
 in the theory of the Riemann zeta function."

FibonacciZeta::usage =
"FibonacciZeta[s] gives the Fibonacci zeta function.
 ZF[s]=Sum[1/Fibonacci[k]^s,{k,1,Infinity}]."

RiemannPrimeR::usage =
"RiemannPrimeR[z] gives the Riemann's prime-approximating
 function R(z)=1+Sum[Log[z]^n/(n! n Zeta[n+1]),{n,1,Infinity}]
 or R(z)=Sum[MoebiusMu[n] LogIntegral[z^(1/n)]/n,{n,1,Infinity}]."

RiemannPrimeRExp::usage =
"RiemannPrimeRExp[z] gives the Riemann's prime-approximating
 function R(Exp[z])=1+Sum[z^n/(n! n Zeta[n+1]),{n,1,Infinity}]
 or R(Exp[z])=Sum[MoebiusMu[n] LogIntegral[Exp[z/n]]/n,{n,1,Infinity}]."

RiemannExpIntegral::usage =
"RiemannExpIntegral[z] gives the Riemann's integral function
 in prime number-approximating theory 
 ri(z)=Integrate[1/(x (Exp[2 x]-1)),{x,z,Infinity}]."

RiemannLogIntegral::usage =
"RiemannLogIntegral[z] gives the Riemann's integral function
 in prime number-approximating theory 
 Ri(z)=Integrate[1/(x (x^2-1) Log[x]),{x,z,Infinity}] 
 and rerated ri(Log[z])=Ri(z)."

RiemannTermNonTrivialZero::usage =
"RiemannTermNonTrivialZero[n,z] gives the term of
 summation along the non trivial zeros of Riemann 
 zeta function on Riemann-Von Mangoldt's formulae 
 of prime number approximating."

RiemannVonMangoldtPi::usage =
"RiemannVonMangoldtPi[n,z] gives the Riemann-Von Mangoldt's
 formulae of prime number approximating."




Begin["SpecialFunctions`Zeta`Private`"]







Attributes[RiemannXi]={Listable}

Attributes[DirichletChi]={Listable}

Attributes[DirichletL]={Listable}

Attributes[PeriodicZetaF]={Listable}

Attributes[HurwitzZeta]={Listable}

Attributes[ZetaPrime]={Listable}

Attributes[StieltjesFGamma]={Listable}

Attributes[SitaramachandraraoDelta]={Listable}

Attributes[BellExponentB]={Listable}

Attributes[BellExponentB2]={Listable}

Attributes[GlaisherRamanujanG]={Listable}

Attributes[GlaisherRamanujanG2]={Listable}

Attributes[LandauHurwitzP]={Listable}

Attributes[RamanujanSiegelTheta]={Listable}

Attributes[RamanujanSiegelZ]={Listable}

Attributes[FibonacciZeta]={Listable}

Attributes[setPrecRPRExp]={Listable}

Attributes[RiemannPrimeR]={Listable}

Attributes[RiemannPrimeRExp]={Listable}

Attributes[RiemannExpIntegral]={Listable}

Attributes[RiemannLogIntegral]={Listable}

Attributes[RiemannTermNonTrivialZero]={Listable}

Attributes[RiemannVonMangoldtPi]={Listable}





(*****************************************************************************)
(*                               RiemannXi[s]                                *)
(*****************************************************************************)

RiemannXi[s_]:=s*(s-1)*Pi^(-s/2)*Gamma[s/2]*Zeta[s]



(*****************************************************************************)
(*                            DirichletChi[m,n]                              *)
(*****************************************************************************)

DirichletChi[m_,0]:=0

DirichletChi[m_,1]:=1

DirichletChi[m_,2]:=0/;(Mod[m,4]===0)

DirichletChi[m_,2]:=1/;(Mod[m,8]===1)

DirichletChi[m_,2]:=-1/;(Mod[m,8]===5)

DirichletChi[m_,n_?PrimeQ]:=JacobiSymbol[m,n]/;n >2

DirichletChi[m_,n_Integer?Positive]:=
  Module[{k,fm=FactorInteger[n]},
  Product[DirichletChi[m,fm[[k,1]]]^fm[[k,2]],
  {k,Length[fm]}]]/;(n >2 && PrimeQ[n]===False)

DirichletChi[m_,n_Integer?Negative]:=
  Sign[m] DirichletChi[m,-n]



(*****************************************************************************)
(*                             DirichletL[s,m]                               *)
(*****************************************************************************)

DirichletL[s_Integer?Positive,m_]:=
  Module[{n},
  -(2 Pi)^s/(-1)^(s/2)/(2 s! Sqrt[m])*
  Sum[DirichletChi[m,n] BernoulliB[s,n/m],{n,1,m}]]/;
  (EvenQ[s]===True && m >0)

DirichletL[s_Integer?Positive,m_]:=
  Module[{n},
  (2 Pi)^s/(-1)^((s+1)/2)/(2 s! Sqrt[-m])*
  Sum[DirichletChi[m,n] BernoulliB[s,-n/m],{n,1,-m}]]/;
  (OddQ[s]===True && m <0)

DirichletL[s_Integer,m_]:=
  Module[{n},
  -Abs[m]^-s/(1-s)*
  Sum[DirichletChi[m,n] BernoulliB[1-s,n/Abs[m]],{n,1,Abs[m]}]]/;
  (s<=0)

DirichletL[s_,1]:=Zeta[s]

DirichletL[s_,-4]:=2^-s LerchPhi[-1,s,1/2]/;(Re[s]>=-4)

DirichletL[s_,8]:=
  4^-s (LerchPhi[-1,s,1/4]-LerchPhi[-1,s,3/4])/;(Re[s]>=-4)

DirichletL[s_,-8]:=
  4^-s (LerchPhi[-1,s,1/4]+LerchPhi[-1,s,3/4])/;(Re[s]>=-4)

DirichletL[s_,m_]:=
  Module[{n},
  Abs[m]^-s*Sum[DirichletChi[m,n] Zeta[s,n/Abs[m]],{n,1,Abs[m]-1}]]/;
  (Re[s]>=-4 && MemberQ[{1,-4,8,-8},m]===False)

DirichletL[s_,m_]:=
  (Pi/m)^(s-1/2) Gamma[1/2-s/2]/Gamma[s/2] DirichletL[1-s,m]/;
  (Re[s]<-4 && m >0)

DirichletL[s_,m_]:=
  (-Pi/m)^(s-1/2) Gamma[1-s/2]/Gamma[1/2+s/2] DirichletL[1-s,m]/;
  (Re[s]<-4 && m <0)



(*****************************************************************************)
(*                            PeriodicZetaF[s,a]                             *)
(*****************************************************************************)

PeriodicZetaF[s_,a_]:=
  Exp[2 Pi I a]*LerchPhi[Exp[2 Pi I a],s,1]



(*****************************************************************************)
(*                             HurwitzZeta[s,a]                              *)
(*****************************************************************************)

HurwitzZeta[s_,a_]:=
  Zeta[s]/;(Re[a]===N[0] || Re[a]===N[1])

HurwitzZeta[s_,a_]:=
  Zeta[s,a]/;(Re[s]>-4 && 0<Re[a]<1)

HurwitzZeta[s_,a_]:=
  (Exp[-Pi I (1-s)/2] PeriodicZetaF[1-s,a]+
   Exp[Pi I (1-s)/2] PeriodicZetaF[1-s,-a])*
   Gamma[1-s]/((2 Pi)^(1-s))/;
   (Re[s]<=-4 && 0<Re[a]<1)

HurwitzZeta[s_,a_]:=
  HurwitzZeta[s,a+1]+(-1/a)^s/;(Re[a]<0)

HurwitzZeta[s_,a_]:=
  HurwitzZeta[s,a-1]-(a-1)^(-s)/;(Re[a]>1)



(*****************************************************************************)
(*                            realORcomplex[z,f]                             *)
(*****************************************************************************)

realORcomplex[z_,f_]:=If[Abs[Im[z]]>0,N[f],N[Re[f]]]



(*****************************************************************************)
(*                              ZetaPrime[d,s]                               *)
(*****************************************************************************)

ZetaPrime[d_,s_]:=Infinity/;(N[s]===1.)


ZetaPrime[d_,s_]:=
  realORcomplex[s,Module[{m=20},
     (Log[m]^d)/(m^s)/2+zetaPrIntegTerm[d,s,m]+
     Module[{i},
       Sum[(Log[i]^d)/(i^s),{i,2,m-1,1}]]-
     Module[{j,sdtm=5},
       Sum[zetaPrDTerm[d,s,m,j-1]BernoulliB[j]/(j!),{j,2,2*sdtm,2}]]]]*(-1)^d/;
     (Precision[s]<Infinity && Re[s]>=0.31 && N[s]=!=1. )


zetaPrIntegTerm[d_,s_,m_]:=
  Fold[(Pochhammer[d+1-#2,#2]+(s-1) Log[m] #1)&,1,Range[1,d,1]]*
  m^(1-s)/((s-1)^(d+1))


zetaPrDTerm[d_,s_,m_,k_]:=
  Module[{x},D[(Log[x]^d)/(x^s),{x,k}]/.(x->m)]/;(k>=11)

zetaPrDTerm[d_,s_,m_,1]:=
  m^(-1-s) Log[m]^(-1+d) (d-s Log[m])

zetaPrDTerm[d_,s_,m_,3]:=
  m^(-3-s) Log[m]^(-3+d) (d (2-3 d+d^2)-3 (-1+d) d (1+s) Log[m]+
  d (2+6 s+3 s^2) Log[m]^2-s (2+3 s+s^2) Log[m]^3)

zetaPrDTerm[d_,s_,m_,5]:=
  m^(-5-s) Log[m]^(-5+d) (d (24-50 d+35 d^2-10 d^3+d^4)-
  5 d (-6+11 d-6 d^2+d^3) (2+s) Log[m]+
  5 d (2-3 d+d^2) (7+8 s+2 s^2) Log[m]^2-
  5 (-1+d) d (10+21 s+12 s^2+2 s^3) Log[m]^3+
  d (24+100 s+105 s^2+40 s^3+5 s^4) Log[m]^4-
  s (24+50 s+35 s^2+10 s^3+s^4) Log[m]^5)

zetaPrDTerm[d_,s_,m_,7]:=
  m^(-7-s) Log[m]^(-7+d) (d (720-1764 d+1624 d^2-735 d^3+175 d^4-21 d^5+d^6)-
  7 d (-120+274 d-225 d^2+85 d^3-15 d^4+d^5) (3+s) Log[m]+
  7 d (24-50 d+35 d^2-10 d^3+d^4) (25+18 s+3 s^2) Log[m]^2-
  35 d (-6+11 d-6 d^2+d^3) (21+25 s+9 s^2+s^3) Log[m]^3+
  7 d (2-3 d+d^2) (232+420 s+250 s^2+60 s^3+5 s^4) Log[m]^4-
  7 (-1+d) d (252+696 s+630 s^2+250 s^3+45 s^4+3 s^5) Log[m]^5+
  d (720+3528 s+4872 s^2+2940 s^3+875 s^4+126 s^5+7 s^6) Log[m]^6-
  s (720+1764 s+1624 s^2+735 s^3+175 s^4+21 s^5+s^6) Log[m]^7)

zetaPrDTerm[d_,s_,m_,9]:=
  m^(-9-s) Log[m]^(-9+d)*
  (d (40320-109584 d+118124 d^2-67284 d^3+22449 d^4-4536 d^5+546 d^6-36 d^7+d^8)-
  9 d (-5040+13068 d-13132 d^2+6769 d^3-1960 d^4+322 d^5-28 d^6+d^7) (4+s) Log[m]+
  6 d (720-1764 d+1624 d^2-735 d^3+175 d^4-21 d^5+d^6) (91+48 s+6 s^2) Log[m]^2-
  42 d (-120+274 d-225 d^2+85 d^3-15 d^4+d^5) (108+91 s+24 s^2+2 s^3) Log[m]^3+
  21 d (24-50 d+35 d^2-10 d^3+d^4) (1069+1296 s+546 s^2+96 s^3+6 s^4) Log[m]^4-
  21 d (-6+11 d-6 d^2+d^3) (3204+5345 s+3240 s^2+910 s^3+120 s^4+6 s^5) Log[m]^5+
  2 d (2-3 d+d^2) (59062+134568 s+112245 s^2+45360 s^3+9555 s^4+1008 s^5+42 s^6) Log[m]^6-
  6 (-1+d) d (18264+59062 s+67284 s^2+37415 s^3+11340 s^4+1911 s^5+168 s^6+6 s^7) Log[m]^7+
  3 d (13440+73056 s+118124 s^2+89712 s^3+37415 s^4+9072 s^5+1274 s^6+96 s^7+3 s^8) Log[m]^8-
  s (40320+109584 s+118124 s^2+67284 s^3+22449 s^4+4536 s^5+546 s^6+36 s^7+s^8) Log[m]^9)




ZetaPrime[d_,s_]:=
  realORcomplex[s,Module[{m=3},
     (Log[m]^d)/(m^s)/2+zetaPrIntegTerm[d,s,m]+
     Module[{i},
       Sum[(Log[i]^d)/(i^s),{i,2,m-1,1}]]-
     Module[{j,sdtm=20},
       Sum[zetaPrDTerm[d,s,m,j-1]BernoulliB[j]/(j!),{j,2,2*sdtm,2}]]]]*(-1)^d/;
     (Precision[s]<Infinity && nearlyEvenQ[s]===True && Re[s]<0.31)

ZetaPrime[d_,s_]:=
  zetaPrimeNegative[d,s]/;
  (Precision[s]<Infinity && nearlyEvenQ[s]=!=True && Re[s]<0.31)


nearlyEvenQ[v_]:=
  EvenQ[Chop[IntegerPart[Re[v]]]+Chop[FractionalPart[Re[v]]]+Chop[Im[v]]*I]


zetaPrimeNegative[d_,s_]:=
  Module[{x},
  D[Pi^(x-1/2) Gamma[(1-x)/2]/Gamma[x/2] Zeta[1-x],{x,d}]/.
  Derivative[d][Zeta][1-x]->ZetaPrime[d,1-x]/.x->s]/;(d>4)


zetaPrimeNegative[1,s_]:=
  (Pi^(s-1/2) Gamma[(1-s)/2]*
  ((2 Log[Pi]-PolyGamma[0,(1-s)/2]-PolyGamma[0,s/2])*
  Zeta[1-s]-2 ZetaPrime[1,1-s]))/(2 Gamma[s/2])

zetaPrimeNegative[2,s_]:=
  (Pi^(s-1/2) Gamma[(1-s)/2]*
  ((4 Log[Pi]^2-(4 Log[Pi]-PolyGamma[0,(1-s)/2]-PolyGamma[0,s/2])*
  (PolyGamma[0,(1-s)/2]+PolyGamma[0,s/2])+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])*
  Zeta[1-s]+4 (-2 Log[Pi]+PolyGamma[0,(1-s)/2]+PolyGamma[0,s/2])*
  ZetaPrime[1,1-s]+4 ZetaPrime[2,1-s]))/(4 Gamma[s/2])

zetaPrimeNegative[3,s_]:=
  (Pi^(s-1/2) Gamma[(1-s)/2]*
  ((8 Log[Pi]^3-PolyGamma[0,(1-s)/2]^3+PolyGamma[0,(1-s)/2]^2*
  (6 Log[Pi]-3 PolyGamma[0,s/2])+6 Log[Pi] PolyGamma[0,s/2]^2-
  PolyGamma[0,s/2]^3+6 Log[Pi] (PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])-
  3 PolyGamma[0,s/2] (4 Log[Pi]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])-
  3 PolyGamma[0,(1-s)/2] (4 Log[Pi]^2-4 Log[Pi] PolyGamma[0,s/2]+
  PolyGamma[0,s/2]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])-
  PolyGamma[2,(1-s)/2]-PolyGamma[2,s/2]) Zeta[1-s]-
  6 (4 Log[Pi]^2-(4 Log[Pi]-PolyGamma[0,(1-s)/2]-PolyGamma[0,s/2])*
  (PolyGamma[0,(1-s)/2]+PolyGamma[0,s/2])+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])*
  ZetaPrime[1,1-s]+12 (2 Log[Pi]-PolyGamma[0,(1-s)/2]-PolyGamma[0,s/2])*
  ZetaPrime[2,1-s]-8 ZetaPrime[3,1-s]))/(8 Gamma[s/2])

zetaPrimeNegative[4,s_]:=
  (Pi^(s-1/2) Gamma[(1-s)/2]*
  ((16 Log[Pi]^4+PolyGamma[0,(1-s)/2]^4-8 Log[Pi] PolyGamma[0,s/2]^3+
  PolyGamma[0,s/2]^4+4 PolyGamma[0,(1-s)/2]^3 (-2 Log[Pi]+PolyGamma[0,s/2])+
  24 Log[Pi]^2 PolyGamma[1,(1-s)/2]+3 PolyGamma[1,(1-s)/2]^2+
  6 PolyGamma[0,s/2]^2 (4 Log[Pi]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])+
  6 PolyGamma[0,(1-s)/2]^2 (4 Log[Pi]^2-4 Log[Pi] PolyGamma[0,s/2]+
  PolyGamma[0,s/2]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])-
  24 Log[Pi]^2 PolyGamma[1,s/2]-6 PolyGamma[1,(1-s)/2] PolyGamma[1,s/2]+
  3 PolyGamma[1,s/2]^2-8 Log[Pi] PolyGamma[2,(1-s)/2]-
  8 Log[Pi] PolyGamma[2,s/2]+4 PolyGamma[0,s/2]*
  (-8 Log[Pi]^3+6 Log[Pi] (-PolyGamma[1,(1-s)/2]+PolyGamma[1,s/2])+
  PolyGamma[2,(1-s)/2]+PolyGamma[2,s/2])+4 PolyGamma[0,(1-s)/2]*
  (-8 Log[Pi]^3-6 Log[Pi] PolyGamma[0,s/2]^2+
  PolyGamma[0,s/2]^3+3 PolyGamma[0,s/2]*
  (4 Log[Pi]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])+
  6 Log[Pi] (-PolyGamma[1,(1-s)/2]+PolyGamma[1,s/2])+
  PolyGamma[2,(1-s)/2]+PolyGamma[2,s/2])+PolyGamma[3,(1-s)/2]-PolyGamma[3,s/2])*
  Zeta[1-s]+8 ((-8 Log[Pi]^3+PolyGamma[0,(1-s)/2]^3-6 Log[Pi] PolyGamma[0,s/2]^2+
  PolyGamma[0,s/2]^3+3 PolyGamma[0,(1-s)/2]^2 (-2 Log[Pi]+PolyGamma[0,s/2])+
  3 PolyGamma[0,s/2] (4 Log[Pi]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])+
  3 PolyGamma[0,(1-s)/2] (4 Log[Pi]^2-4 Log[Pi] PolyGamma[0,s/2]+
  PolyGamma[0,s/2]^2+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])+
  6 Log[Pi] (-PolyGamma[1,(1-s)/2]+PolyGamma[1,s/2])+
  PolyGamma[2,(1-s)/2]+PolyGamma[2,s/2]) ZetaPrime[1,1-s]+
  3 (4 Log[Pi]^2-(4 Log[Pi]-PolyGamma[0,(1-s)/2]-PolyGamma[0,s/2])*
  (PolyGamma[0,(1-s)/2]+PolyGamma[0,s/2])+PolyGamma[1,(1-s)/2]-PolyGamma[1,s/2])*
  ZetaPrime[2,1-s]+4 (-2 Log[Pi]+PolyGamma[0,(1-s)/2]+PolyGamma[0,s/2])*
  ZetaPrime[3,1-s])+16 ZetaPrime[4,1-s]))/(16 Gamma[s/2])



(*****************************************************************************)
(*                            StieltjesFGamma[s]                             *)
(*****************************************************************************)

setPrecSMax[x_]:=
  Floor[12.484807387941489+3.691271417644542*x+0.004885859743489576*x^2]

sdTermMax[x_]:=
  Floor[2.0589255234365997+0.05430589913594137*x+0.0023200624083181613*x^2]

maxSFRegion[z_]:=
  If[N[Abs[z]]===0.,0,If[Abs[Arg[z]]<N[ArcTan[3]],Re[z],Im[z]/3]]


setPrecStieltjes[z_]:=
  Module[{spsm=setPrecSMax[maxSFRegion[z]]},
    SetPrecision[z*10^spsm,spsm]/(10^spsm)]




StieltjesFGamma[z_]:=Infinity/;(N[z]===-1.)

StieltjesFGamma[0]:=EulerGamma-1

StieltjesFGamma[z_]:=
  realORcomplex[z,Module[{s=setPrecStieltjes[z],m=20},
      Log[m]^s/(2 m)-Log[m]^(1+s)/(1+s)+
      Module[{i},Sum[Log[i]^s/i,{i,2,m-1,1}]]-
      Module[{j,sdtm=sdTermMax[maxSFRegion[s]]},
        Sum[stieltjesDTerm[s,m,j-1]BernoulliB[j]/(j!),{j,2,2*sdtm,2}]]]]/;
  (Precision[z]<Infinity && N[z]=!=-1. )


stieltjesDTerm[s_,m_,k_]:=
  Module[{x},D[Log[x]^s/x,{x,k}]/.(x->m)]/;(k>=11)

stieltjesDTerm[s_,m_,1]:=
  (s-Log[m])*Log[m]^(s-1)/(m^2)

stieltjesDTerm[s_,m_,3]:=
  (s (2-3 s+s^2)-6 (-1+s) s Log[m]+11 s Log[m]^2-6 Log[m]^3)*
  Log[m]^(s-3)/(m^4)

stieltjesDTerm[s_,m_,5]:=
  (s (24-50 s+35 s^2-10 s^3+s^4)-15 s (-6+11 s-6 s^2+s^3) Log[m]+
  85 s (2-3 s+s^2) Log[m]^2-225 (-1+s) s Log[m]^3+
  274 s Log[m]^4-120 Log[m]^5)*
  Log[m]^(s-5)/(m^6)

stieltjesDTerm[s_,m_,7]:=
  (s (720-1764 s+1624 s^2-735 s^3+175 s^4-21 s^5+s^6)-
  28 s (-120+274 s-225 s^2+85 s^3-15 s^4+s^5) Log[m]+
  322 s (24-50 s+35 s^2-10 s^3+s^4) Log[m]^2-
  1960 s (-6+11 s-6 s^2+s^3) Log[m]^3+
  6769 s (2-3 s+s^2) Log[m]^4-
  13132 (-1+s) s Log[m]^5+13068 s Log[m]^6-5040 Log[m]^7)*
  Log[m]^(s-7)/(m^8)

stieltjesDTerm[s_,m_,9]:=
  (s (40320-109584 s+118124 s^2-67284 s^3+22449 s^4-4536 s^5+546 s^6-36 s^7+s^8)-
  45 s (-5040+13068 s-13132 s^2+6769 s^3-1960 s^4+322 s^5-28 s^6+s^7) Log[m]+
  870 s (720-1764 s+1624 s^2-735 s^3+175 s^4-21 s^5+s^6) Log[m]^2-
  9450 s (-120+274 s-225 s^2+85 s^3-15 s^4+s^5) Log[m]^3+
  63273 s (24-50 s+35 s^2-10 s^3+s^4) Log[m]^4-
  269325 s (-6+11 s-6 s^2+s^3) Log[m]^5+
  723680 s (2-3 s+s^2) Log[m]^6-
  1172700 (-1+s) s Log[m]^7+1026576 s Log[m]^8-362880 Log[m]^9)*
  Log[m]^(s-9)/(m^10)



(*****************************************************************************)
(*                        SitaramachandraraoDelta[s]                         *)
(*****************************************************************************)

SitaramachandraraoDelta[s_]:=
  Module[{m=20,sdtm=8,sp=SetPrecision[s,100]},
    (Log[m]^sp)/2+
    Gamma[sp+1]*Exp[-Pi*I*sp]*GammaRegularized[sp+1,0,-Log[m]]+
    Sum[Log[i]^sp,{i,2,m-1}]-
    sp*(Log[m]^sp)*Sum[zetaPDerivTerm[sp,m,k-1]*BernoulliB[k]/(k!),{k,2,2*sdtm,2}]]/;
  (Precision[s]<Infinity)

zetaPDerivTerm[s_,m_,k_]:=
  Sum[(-1)^i*symmetryExprSI[k-1,i]*Log[m]^i*Product[s-j,{j,1,k-i-1}],{i,0,k-1}]*
  (m*Log[m])^(-k);

symmetryExprSI[m_,n_]:=
  symmetryExprSI[m,n]=symmExprI[m,n];

symmExprI[m_,n_]:=
  m*symmExprI[m-1,n-1]+symmExprI[m-1,n]/;(0<n<m)

symmExprI[m_,n_]:=1/;(n===0)

symmExprI[m_,n_]:=m!/;(n===m)



(*****************************************************************************)
(*                    BellExponentB[s], BellExponentB2[s]                    *)
(*****************************************************************************)

BellExponentB[z_]:=
  Module[{s=0,so=1,k1=0,faf},faf=1;
   While[so!=s,so=s; s+=((k1+1)^z/faf);
   faf*=(k1+1);k1++];s]/E/;(Precision[z]<Infinity)

BellExponentB2[z_]:=
  Module[{s=0,so=1,k1=0,mf,faf},mf=1;faf=1;
   While[so!=s,so=s; s+=(mf/faf*(k1+1)^z);
   mf*=(-1);faf*=(k1+1);k1++];s]/E/;(Precision[z]<Infinity)



(*****************************************************************************)
(*               GlaisherRamanujanG[s], GlaisherRamanujanG2[s]               *)
(*****************************************************************************)

GlaisherRamanujanG[z_]:=
  Module[{s=0,so=1,k1=1,expf},expf=(E^(2 Pi));
   While[so!=s,so=s; s+=(k1^z/(expf-1));
   expf*=(E^(2 Pi));k1++];s]/;(Precision[z]<Infinity)

GlaisherRamanujanG2[z_]:=
  Module[{s=0,so=1,k1=1,mf,expf},mf=1;expf=(E^(2 Pi));
   While[so!=s,so=s; s+=(mf*k1^z/(expf-1));
   mf*=(-1);expf*=(E^(2 Pi));k1++];s]/;(Precision[z]<Infinity)



(*****************************************************************************)
(*                            LandauHurwitzP[z]                              *)
(*****************************************************************************)

LandauHurwitzP[z_]:=
  Module[{s=0,so=1,k1=1},
    While[(so!=s && k1<200),so=s;
      s+=lhpLogZetaSum[k1,z];
      k1+=10];s]/;(Precision[z]<Infinity)

lhpLogZetaSum[k_,z_]:=Sum[Log[Zeta[i z]] MoebiusMu[i]/i,{i,k,k+9}]



(*****************************************************************************)
(*                         RamanujanSiegelTheta[t]                           *)
(*****************************************************************************)

RamanujanSiegelTheta[t_]:=RamanujanTauTheta[t]



(*****************************************************************************)
(*                           RamanujanSiegelZ[t]                             *)
(*****************************************************************************)

RamanujanSiegelZ[t_] :=
  Module[{z},z=RamanujanTauDirichletSeries[6+I t]*
  Exp[I RamanujanSiegelTheta[t]];
  If[Head[t]=!=Complex, z=Re[z]]; z]/;
  (NumberQ[t] && Precision[t]<Infinity)



(*****************************************************************************)
(*                             FibonacciZeta[z]                              *)
(*****************************************************************************)

FibonacciZeta[z_]:=
  Module[{s=0,so=-1,k=1},
  While[so!=s,so=s;s+=Fibonacci[k]^(-z);k++];s]/;
  (Precision[z]<Infinity && Re[z]>=0.5)

FibonacciZeta[z_]:=
  Module[{s=0,so=-1,k=0},
  While[so!=s,so=s;
    s+=SetPrecision[Binomial[-z,k]/(N[GoldenRatio]^(z+2 k)+(-1)^(k+1)),100];
    k++];s]*5^(z/2)/;
    (Precision[z]<Infinity && Re[z]<0.5)



(**************************************************************************)
(*                            RiemannPrimeR[z]                            *)
(**************************************************************************)

RiemannPrimeR[z_]:=0/;(N[z]===0.)

RiemannPrimeR[z_]:=
  RiemannPrimeRExp[Log[z]]/;
	(N[z]=!=0. && Precision[z]<Infinity)


(**************************************************************************)
(*                         setPrecRPRExp[z,prec]                          *)
(**************************************************************************)

setPrecRPRExp[z_,prec_]:=SetPrecision[z*(10^prec),100]/(10^prec)


(**************************************************************************)
(*                           RiemannPrimeRExp[z]                          *)
(**************************************************************************)

RiemannPrimeRExp[z_]:=
  Module[{s=0,so=1,zpr=setPrecRPRExp[z,30],k1=2,g1,zf},
    zf=zpr; g1=1;
	While[so!=s,so=s; s+=(zf/g1/(k1-1)/Zeta[k1]);
	g1*=k1; zf*=zpr; k1++];s]+1/;
	(Re[z]>-50 && Precision[z]<Infinity)



RiemannPrimeRExp[z_]:=
  1/Pi*trivialZeroTerm[z]+1/2*nonTrivialZeroTerm[z]/;
  (Re[z]<=-50 && Precision[z]<Infinity)


trivialZeroTerm[z_]:=
  Module[{s=0,so=1,k1=1,zf,mf},mf=-1;zf=(2 Pi/z)^3;
    While[(so!=s && k1<takeTermFunc[z]),so=s;
    s+=(mf*zf/(2*k1+1)/Zeta[2*k1+1]);
    mf*=(-1);zf*=(2 Pi/z)^2;k1++];s];

nonTrivialZeroTerm[z_]:=
  Module[{zetaNTZL=Take[ZetaNonTrivialZeroList,takeTermFunc[z]],
          zetaPVL=Take[zetaPrimeValueList,takeTermFunc[z]]},
    Map[(-2 Pi/z)^#/(#*Cos[# Pi/2])&,
      Join[Map[(1/2+#*I)&,zetaNTZL],Map[(1/2-#*I)&,zetaNTZL]]].
      Join[1/zetaPVL,1/Conjugate[zetaPVL]]];

takeTermFunc[z_]:=Min[340,Floor[20+5000000/Abs[z]]];

zetaPrimeValueList=
  {0.78329651186703092864965720923906507479613917974328357030+
   0.12469982974817108940992849150890537284325083787797435941*I,
   1.10929556346267156565222589412963157936976669966329567697-
   0.24872978851649745822082995796164610320459142299973109057*I,
   1.29579560500883517344426576845690517186370699933929898138+
   0.45003670943786714356857517109274557361493314509528196263*I,
   1.12013084524449343703787165229074797607701472012842893730-
   0.66750946934949228255188338608610196733519190031896782038*I,
   1.16057006749356257037876786852867990203921458214111353700+
   0.75055415034226382161380717883765296032778751741504461663*I,
   1.85346624998295542544059666058751969830388523850685478820-
   0.56100442049576069098496234168430208392786049249863805838*I,
   1.45951733467199078523479190298937820787052896989009058275-
   0.30286893544609256109180117404561781304400142891818618928*I,
   1.46408757414579939095750188891917719636584288508214670825+
   1.10372579262141035758266251402754109013991098788278141453*I,
   1.03392979847194648887639382416186068225572193428293310315-
   1.17886041598781917670538517197757211784226612500241157511*I,
   1.26089364678424344577294730913403365521766193750813144612+
   0.65078102523623133751555302309472974684490043700285893224*I,
   2.34497063266744507318389774804788360067780202294550323907+
   0.62401819239326753929260820135334118148582777940289796017*I,
   2.21680853789142933319987190753117956022128643845383204864-
   0.83239157594724129259778350060344284477012489046801860713*I,
   1.26015151261487028671220404961899996155525638227079957795-
   0.59088157874629211465030260945290137757697661102719376768*I,
   0.85593650398215791084181268286815652638324349254583276894+
   1.41547835276601339193976963897622880015844521118537924003*I,
   1.65158207573055864068764312283380091964287529650362250421-
   1.58310121727212044535081902908990755578321245184665620601*I,
   1.78007607549082739220312831917727975407121916553670858982+
   0.11173723420259735027419242065424670489460616266497886723*I,
   2.11201794220059005784356033789496215638645957484687235267+
   0.56509828998751021456408968554337637425038352838519619454*I,
   2.78442039783222080489430054675873517338693055101582399641+
   1.01757791078938291674031724392179128049694177997392811756*I,
   0.97575697422686857747267025639618351396082133490092475493-
   1.48819281939130251434428252220169662667235298047402203690*I,
   1.36812118170056652974308169570090476294420581866045210754+
   0.50266771858187695302772464887157162011971378043473848593*I,
   1.96736764082021826953247373682647479750198199638433104120+
   1.75724449650986005865483871210266347637864027813999002182*I,
   2.01039191929462722599273140797208651916337466841737355836-
   1.69079538293161935507851004269313022444168464726533218548*I,
   2.15519310618320970650237321714741412205371762043262689886+
   0.16861318780693095092662178955686465374524016100492125749*I,
   1.71982088312273272953989159842835878693787946695467668237-
   0.53274094643464034843577182999152211129311878403392405522*I,
   1.15019136183959193290011592720428705746713040296498834981+
   1.84771246779888508246895784492563937465867518283086303359*I,
   2.17985014757685793159255030958567093426377270108570019095-
   2.06852108511380173251078045579767840310196137226785831933*I,
   1.27362844322013382880926991712055321806670260727303406375-
   0.75266287773737742000029830646837125165341715612372046167*I,
   0.98458392516445658914357876217929675400954568011659789429+
   1.37794742374200376774775231872640025315618981487097786361*I,
   3.51356243707126092649400618070129788333445708177622545956+
   0.12448741421238858648655657147367408576199947151205404242*I,
   3.04491049754499565355816132133550100937673462738429916883-
   0.82481491661098156581813325061889093375189325252314441490*I,
   1.91818604353880260597108260725740970008140159030986335786-
   1.00908286918866669667717884133645119744515158139122705904*I,
   1.82114826275406337973088098886711106493187863743787175729+
   0.44058627788052815230700674866082185274293630858952607993*I,
   1.75015370683945824460532120041915752529692804868773543077+
   2.41500544032005740171109328686873361743071486884534589798*I,
   0.23129777527349576314647674009602816255596349719475425405-
   1.57394141239030850731863742606655068050105247562034975733*I,
   1.19351557883738382928677256532146843557389275625372431049+
   0.65440965801956660680145435580738009885638609468283621400*I,
   2.53120364420837134137371599035472655349315774623375694761+
   0.27666197355461031815632483904723573342882104758147268520*I,
   2.77067940680153780263562232789033781543615260998563915561+
   1.43231769057958012232400249885643388854529207429103265282*I,
   3.85176223825316618843536584376252133383134062262160794830-
   0.52677660380479812974790460950742878327163538181660195406*I,
   1.60022422190411227009647977112493335067151590466690142739-
   1.64500147161614252039549879931442027708468616271357110239*I,
   1.55913850848594972064876518130078351394576775001814833510+
   0.00470204224217882309074757682329060218629376017410658903*I,
   0.85372476859176649758970202787060414159108611556341767817+
   2.15283888326750315075037376598796830513509001442374698535*I,
   3.35589030991094345093684019885669375570644908533119788131-
   2.06134296665919649955467506737656112990541118101791009116*I,
   2.03266468222803426423694930910161477019543464639102674293-
   1.16719502343194192154946661017997788051049664667094180004*I,
   2.19254709479093399957158619280408185292042515573068312435+
   0.75729694376567702814603015368782186451581155554679537670*I,
   2.24467443586542027705619359590766966202477409836842123770-
   0.44964145533860147141870378759561344218712659927962055005*I,
   1.48083085512790586577378291084141396672767676316793530805+
   2.39700409919932503827014135432754283788382598910853652697*I,
   1.67723153642901450638243277772245050014158875278976850391-
   2.67790008829942728546010862476290839567098115906375364585*I,
   1.67450834286548934581698887068532664176517758504378456099-
   0.66439338629038072287676305257437774111805615436210433537*I,
   1.65588376695133815009419252671230438254479939436877142627+
   1.15367611928938874773894335768547385977757336243827363875*I,
   2.98549070431852450975549389468160008918151489574237067981+
   2.26881665198302303031217280015237561080665182703213475634*I,
   2.40197726307817280034331586379875189511936247999169614406-
   2.18622766797894515556697520136790276051530394029157824792*I,
   2.77964464362507257416083674664413424087670761958922669967+
   0.45844185277014759688989262914844907036630373444139065125*I,
   1.06049740336130402907650511275726756571491507989432485748-
   1.22485805638130492867739484422232931111457467943639317797*I,
   0.98342887322961815604918851945913275641831383795785886898+
   1.23946692468225744202774625286671828985928936100336375070*I,
   3.25140855012216532700607500700048833993557472051337043626+
   2.72445452162401327744364032476465671877269560087613106516*I,
   1.38668494611245730637530689367654760007061895475512294284-
   2.76779731178861931880286554010703404856089406940437085268*I,
   1.63553326262456998722093576062547955492282720481928643091-
   0.60293605671306903296297455967576618488597399710394667959*I,
   1.53596362255124779168708049466288764074818752682111688571+
   1.48403906818466379796500238427206159743213419099501316693*I,
   3.56327068879384441908198052220912661246728194267797353590+
   0.44299987094204019628019834425153018517485105014527331872*I,
   3.96306328418196314376334760510499181130414286362151496082+
   1.10571619919804708000046344102980780909180798527575516096*I,
   2.64712802884179854843203385240758022842655351295227290482-
   2.12462494148884723748663038324310539640809903151025219525*I,
   2.38949604476515989284198257717852653348488501355979767564-
   0.56796403555683937553689517929984604430695336227447828213*I,
   1.49531236935544403824008433100842606132156642115144670736-
   0.35152444542834576718045871152125767351754912047425921730*I,
   0.01357458217488843227556766581494995385541968623424540629+
   1.97889090994790738849600798839386704039335981292232311406*I,
   1.63681020530521657295451044870900808343962924796654612968-
   3.07833081491792223671292112134445980510492915735756490468*I,
   2.32082621096851108856735995446715125360990167051348933639-
   0.39938569675487776965223098321424888282381255020279234894*I,
   2.62429608789906965984132953583674371195472396534721779005+
   0.42795162222890123693354948438147919004000642776697302621*I,
   2.81374814297941951370670583397526727411134068081982815012+
   0.19617808186310369498667746117588546140800764860284729159*I,
   2.82690429504959797127060670571946791584588695825256858923+
   2.07414867907533440450135620832580882073430607920381056629*I,
   4.99664043118419777680921702769134875338932860347024879200-
   0.37394162169238129476642791693640278970929806882683328144*I,
   0.20418884303568093663731372314059628945577511505273803452-
   1.48032087261494864782858700817934766002620937960015049378*I,
   1.09244437013247441139925709198875662930482388499606479450+
   0.57209342706809734450196877253906138899636262362185240052*I,
   1.84830859755516972990700215607519880586150588819012858959+
   2.15060319402119008470172759469996916636753796510441312237*I,
   4.84494448488647089515531964877104647826011464406912779541+
   1.41336291230705727842217290490267044824358073770661062935*I,
   1.42756675727225583391133267611121600183988924177982849801-
   2.37339996880301581907868942559855155615259041359865614959*I,
   2.27651519827735945730302359843560130100994718679968707523+
   0.72984536051445257277206948632084378012087225165316302783*I,
   2.72490609382241882391765622165370834825127280735936454256-
   0.83554496929371833128140268909604383622244838294396969625*I,
   2.17532446326956547496372492575426704773508047903283552730+
   0.15802261220259494192776518443500524842356083783674028370*I,
   0.99274406362597852368981522659120167921656999199059354246+
   2.99780322800829317632085416372953345438326885860247863966*I,
   1.14109554242828594245438631463258863196677831669480107622-
   3.18433989572340669851976326112983065521099960726212066013*I,
   2.18071290780741507790740151093328547451145384356583383326-
   0.48084393200486647214890730226325813996317568914002673318*I,
   2.07572436178719569909486683452420569270151923273489075893-
   0.04997022140009529913935470369526231634098072547634762930*I,
   1.46963087966580927222497739605010438140206955326278492000+
   2.38365160386196151371880390786945491615222264563388620453*I,
   4.40148734822339753915557212896725090878099047748493280494-
   1.01541837430430432677421538694036817807516293630424926502*I,
   4.11774796816642235254745582151400309478916954661455440428-
   0.04432370895622694263855000931811118943969372392248283499*I,
   2.76507029347508183275166741303522468336400884702650282125-
   1.82039918608080889978029701408634545734355579890417748228*I,
   1.95301149831556268320109075070932063930915070852141934291-
   0.73068288450672476210041818518838928263268143964299050273*I,
   1.73392034558693999411979798893655161839498105090038259400+
   1.36923980029440202876965891452065226327729689766575674749*I,
   2.59392346622696572348674433652017611815072086387740322174+
   3.57204019576564463307958647250247441808950730431268045448*I,
   2.04580604233898508582464532051732713292275772770240855903-
   3.58549162163851929558093585636484926356339562043516807231*I,
   0.98624089278118403525923152377108713860526713577797258011-
   1.09812018672898300212756662293362580529903374092178309895*I,
   0.83597337354405889389607365214681141984033065711576267744+
   1.38659700256709548099693512298361940012400538425915214510*I,
   2.41075539752980584771235297934143927993857485562556106126-
   1.09484888043718433175650112547112409556458342991483302173*I,
   1.63287835693795914135871271259480566291344830992581584598+
   2.38083583419161616004690369405373774158702688448767929275*I,
   4.97561132698729733089690623117798572406582162326308781524-
   1.30940771108314289243056266926302701812202113536921643521*I,
   3.15270126985119423337098607996167108472528878617423775017-
   1.96736705696721558339170734181375006895128877050564905331*I,
   0.96413903323495990353392202138746850694574812556746851639-
   1.12151618128038595715289374050018394091020897543807970465*I,
   0.85147170944784473372217287692519453601906697721978727414+
   1.19456158033701678041684594825835278101496273696495062988*I,
   2.29168685121596087452326542407576626739408691516139338487+
   3.66009157254666410814593540830638118565134952134492653856*I,
   2.24558489653549433174954350889813223111838823375300789975-
   3.30417462926310558637859097673033784977332457585649712409*I,
   2.92547554792976410352037991611323004010776885635263072459-
   0.27442911535961398237866903876158528440443425373913426917*I,
   2.84527675279528886442827638455223283599087887011094393761-
   0.57472347651261262012773846214822003918808032401773226226*I,
   2.84806763895924948439048881594428894727766265859902651626+
   0.63922589252516810560457771998967101586224395217511923766*I,
   3.00139968350572516845944921777488469159664739264250160379+
   0.37382823264076425372159136989872116804127924042532117358*I,
   2.32658251225255204847229611487754103877899443810995534099+
   3.50058824947910133329760884798569536465372868612017780796*I,
   0.21376793227560918411998993510065666364267443205225630469-
   2.78151639060071243911722753183914439271655230396716076432*I,
   1.84849475651766908845174048047107138975238577741552361488-
   0.23267390335007117324991111932785709540040954726608586602*I,
   2.20442850252931452389917685376992129791257791283872399954+
   0.70430418077375007606285779996755728603467498269294375248*I,
   2.42248487845340680216691968535239937286006269404601997072+
   2.47189715172591648226418870056107711213494124524260213316*I,
   5.43154061242904399862806458249522821474832339663757443159+
   0.78634527339075687393643365697260143511364783365330240338*I,
   2.17647967417135924298547370768276694589816885122148111314-
   2.48731293581681097367586412259746190342871280473186841646*I,
   2.86408607854298685636619362519255959045319253140058883649+
   0.88065291642414993094261780190329924487302879739937791043*I,
   2.03594044785563972528751036610485860450236983854717055634-
   1.71388455914677954149621213978539975701771989355437127907*I,
   1.74301379037630806806323275652471235392556930285866500297+
   0.15898849491430241262954072064597079159057316591863552289*I,
   0.18922432761609749918489023335159333764488513105833865145+
   2.65266415780033713936112508340690053500147551391706809638*I,
   5.24895039855778430505496640418479710523156514238345187011-
   3.03535303000659346279566608080082586045393092080533440099*I,
   1.16262534630444113981274166849034464899383593778055384013-
   2.24477470795527065142808992301538485104685168324013157540*I,
   1.87144999976379038673761914980944599513429812319061761571+
   0.12881237616534699482706546577838801933228720580097223334*I,
   2.06123803007515924288309106641067124610442259529583828658+
   1.95735993095721555642448632053357121054301968554155127099*I,
   4.14559869191317468578855016790475800549796232901190158762+
   0.22139414419343772082351175538873559942355721242459747948*I,
   4.30757641975434202790044889573532527422917047896907457801+
   1.46626165269250323643903582002810695763379527739868875983*I,
   5.01041027546339834737212069498399649215730660069063553623-
   1.19996039264781331740237369284585246512163562318104451950*I,
   0.97929832350917037583444673962026922873794348690590671039-
   1.98332393152255055743768109888231244456078833361834672444*I,
   1.75107570670071308696211913531626867280650808158740553859+
   0.72862732704968183618887376761160208477520094730488213569*I,
   2.39050932167216524288034661476796115484214635397312196257+
   0.31182597478597549079780734677394875328507825729130673707*I,
   0.53213578144865752980098273176530172535622838166473335560+
   3.40695619395308505228231416280452105630770269022124434156*I,
   -0.0517866002888204228996873155727413593103139911720008697-
   2.61806613821648020499025024743371669976402845870706825503*I,
   1.97067711966922346161223059387838927841377812302005484501+
   0.25939200586668943872875998356796716754644067570684757717*I,
   3.15101957270011936701240517036885447182702775297070539991+
   0.56137335667036718671787941455284660908386734940373333149*I,
   2.93392055744284159014271343349890840570520295004955435335-
   0.52693573364777335093385460525809233902422597118090293377*I,
   2.64103515117226303879546410233326354835353154842026736946+
   1.75044716838218635146545764399192832150592684852506116467*I,
   4.52666122940193717131394564840105929585261103247833328766+
   2.68124692225257973401715108711205856114037109330141397031*I,
   4.00677885608530348841929004617477786646072199893426809318-
   3.16740000565069899739889058017918081701559885877943843597*I,
   1.85746999885814680914450392380471499822776968596543501970-
   1.97376265061306985257243477177407826620599958135463890111*I,
   1.15661572615640541771405393012851297212716906256999357229-
   0.46210545248293308052669918602738924820270515873779345506*I,
   -0.0319419071388875974712263666114887466841600125990501455+
   1.55709432124425993393923805273143751540337034256890888020*I,
   5.83959346564513957966571751483869974834576173721063846789+
   0.55746122034049975492918881581571887285752940646415949050*I,
   4.72066698960767308027081569374340482269899691705874052792-
   1.76160142406500704702730921013853488879059047102752122360*I,
   2.19979787066607399304342778379758384580507496899561423007-
   1.90815435452110330057375569122686542175857342321554935680*I,
   2.62475939356580737536410084417718555650188616207225011647+
   1.10561729555125509044422083603898931658442841818899328373*I,
   1.78695030453791435231440136393200097855275015513130411174-
   1.39609741308837884746456178772614673639670731945965006238*I,
   1.49674557575626410504919856134611301725999981579067574694+
   1.54015910939907387427788518424246834934444722134952120033*I,
   2.54730446696528833115499109315226422109119342475416923056+
   4.38113085376571045497571669850679857548520085014538388288*I,
   0.46166532232038003580663684268667910666525107544325017147-
   3.55254559344765441337140006323887634560631754129557857146*I,
   2.00188395371778633852057655089068921927055376133093697750-
   0.75109816460686096053287820860370011461642921338201944968*I,
   2.31454950314431306395539564647562267772729428243414523542+
   0.76096109869782823590745081415734778566721927040285071873*I,
   3.02083984844208517744755224840658347845065368531185620256+
   1.33145966055244289731812255751452260659849515642519224295*I,
   3.83772146707640720922535320388545365925942320276431044080+
   2.85901402810636693429346773209302072965697163639736364692*I,
   3.38518372568965266891505423030235554727344190092803985137-
   2.55153468499883251105744799573456760668765547815894414823*I,
   3.80860510831119506368128743623898170123168449147936156682+
   1.18227196947663126121599040683181901680135683881490414468*I,
   1.22315189291685922507060657126182838681154901281528126802-
   2.35214273635954257175064138385212451021496078575263301242*I,
   1.93006363703676454850362707535739135905009676439911627379+
   0.21938448023962964386887670621839426380642178714058905737*I,
   2.12880906038118150459954179955055892635263071351165582324+
   1.61890606204365824431653804411559561199369074372337079089*I,
   2.50307171702253890501187120669208941839246200589897500366+
   4.25932198780404439819891698531341150349258256916496147385*I,
   3.31460253382513641747528305885122667256244836793808724790-
   4.31520374611947864686346978354063491678798274470292572774*I,
   1.39029393988231200888732754403153353071544299856822213303-
   1.81628739506205341137507028612526589597858458985315119560*I,
   1.92471939440420330858812604083048166906571851556701384642+
   0.81905805999058963275516373729042929021535351501300891709*I,
   3.17861123828915869956781181810803915261092923869172047904+
   1.85953395050042193588022903216764150745369114473846542642*I,
   1.69988712451684786920844346775856580393530323008236567544-
   1.25822595882778017371002232657346802419277610313152643471*I,
   0.43879832897161050956220532704360500835995039852981967026+
   2.27281401975656018523558290216286143380227973828201652368*I,
   4.15611423977371040741717439391838803766572968665415639212-
   3.57337677479835242602562695918010543762103317264417365517*I,
   2.95480915212942138855870828051236830717894547095858909604-
   1.82310835496446971383238268800802283862340642789387649310*I,
   2.10848793013291462796809431003789991916004498566970642157-
   0.98976137378660613488458116388334496346777315703820369997*I,
   1.86674183976098192861061404494459472432086344459255408147+
   0.65849776412344908532527445267358313272717613276452440693*I,
   0.37547554092175788565118471044611751770560172149207173630+
   3.30598008978510569111041413803256819883964753534932952804*I,
   5.06113410075868606150402156961616459864703473041876762496-
   3.57905329307463549976497168726040564383570305369709298075*I,
   1.88329907549036372776462159957993399254479744826277961538-
   2.15366210432413678680474533158708791036248672903268607559*I,
   2.52118854041588818615764618974161086291399634467981302128+
   1.17054541241485349808553285913898463070240804609607179650*I,
   2.55208450237397727971409577691241794526348104643888639375-
   1.48301394475300578569253561230836302849507811392820140867*I,
   2.43218763383247510358198732491485283821063056364564678893+
   1.08653594036721666270163773531334392811633769736111296377*I,
   3.30241634798234320725001557682372634306109518396402432059+
   2.27936246080451864758479115754702161739166466655624063507*I,
   5.60039278765271938511441106894162410411697167773741311539+
   3.08076525839453263544135234448676702803700531322177189660*I,
   0.39459797807566048401858357868041328739086859076466299129-
   3.39977397954942850952264779864201728252462288019984539309*I,
   1.27830852560964447868543669517378668211103732217189764093-
   0.88026054440784750405190482870884273010078003513029042656*I,
   1.11256827259341881893533776642185032507438366129744305308+
   1.45865471143591462996036352069229882351885148498275519228*I,
   3.71167998776268587729565896727514915922113777019396893898+
   1.73981558479164935604465380825570139149448943086667084145*I,
   4.92311228846333953517422186018076030701316085116622423900+
   2.38014394189119177253661289083387395944183445521247652554*I,
   4.30346860572901294389530209803950886936968161514684275337-
   2.62536887768761738592336701126624648529162903172830369492*I,
   3.69408484914962533295939246041483723601081002053714336215-
   0.97193308920555032257627463330046483733692032137611360524*I,
   3.68599353528797093241064335708137437861319319390175673677-
   0.42877358658052806891946690031589606996044010688816299945*I,
   1.95364075018688316415884985132186938553251126706958592594-
   1.32592147294212621466033945577605096047578755455963465862*I,
   1.71043550272849716966327001603984219532001444983131774360+
   1.07409311160120370619593910467157583472483559652677031434*I,
   0.29425217206393487542817846382199743449575133421684862675+
   3.98798246473306959964475053763473006455791947421743102093*I,
   0.23789552605748626044917933607165413052123565699048209609-
   3.52712643212699378494194622919255500784645964225685134650*I,
   2.66326165807788076809588624236393536462197183486227265422-
   0.00493083562400001953159141667800729643016238547451384025*I,
   0.92083030595292650696123331031346240692887536910439725995-
   1.08981247165687166053451734784462962480208387428080517833*I,
   0.47059044545789559813603243817360915201921651945486975245+
   1.43105923906493620819635622498562646607577248023453247939*I,
   4.56705089894583851415594243344447173283271634895419529021+
   0.31455931730027209935630063267521627576975028001901224953*I,
   4.55889156138241097363550117633088176863243589319385677203+
   1.24164427430593006114168801969810806723259296249174847235*I,
   5.72177451553229698354826900325153956768153063003801463771+
   0.57786597402260343747858992374669829375958278466802792378*I,
   3.12273156171196555438733163740755014825554396926042807455-
   3.10409982891791516948607074811340384832649369440711086203*I,
   1.54445675881604218470692041894436070746832144735530727667-
   1.44362018929533844700815107961017656475876538801401851944*I,
   1.69725057378026416131121807555253152046421295994960450052+
   0.98731604946749549485196521170331539666375624029223823245*I,
   2.31202952420091173789872149677311987175393637970921745055+
   2.70747946796218775767335399964158469634266077388486706788*I,
   5.29427480724881713469939319788874140359397930671470113937+
   4.10153843374837590661759408344210069049706700091101251935*I,
   -0.0475848694805014567168080354224135145604166209753915410-
   2.92209288791175502130745888080684150573944835062365786302*I,
   1.97022631173790291884617863553865431157743229943040611464-
   0.14993898581893631051841400739006174515208869368366788817*I,
   2.56621836850073804287388936676531247351684386662367109159+
   1.83274843008951946229100905081316714807996334204536740901*I,
   1.97598092752927809500541316406847425834148838254726253191-
   1.66121447132694077781713619514491587219130763966795031539*I,
   1.72360394821450556988254734453754920142357970700742082491+
   1.72992327565490883480999664278042023735212798758408485452*I,
   3.94528689624175588482762479048258542773387912088836059735+
   3.62073591695136212630378135923174924820626337692280843184*I,
   6.09014487154764011692563538581291115848917165283202115424-
   2.60809795411434100210656854492996096745850097054386827696*I,
   1.33950880225701055515176675445712017374183794010344791783-
   2.73755612563497553848907745389618381206173873952682525892*I,
   2.17359503615249200657311815274863955226033177854675701720-
   0.22040618598904428034199510013060937666675425488965259327*I,
   2.08105123015006041089994854491390977846427636717723032525+
   0.37839303266786644538946178827900464562039518935927509083*I,
   0.37717238233080852254681024533646975049919863336936734492+
   3.14341880381079149016072571117476443291092314138983086484*I,
   5.23068574148895650135698203303218674512116617072948606669-
   2.91475987673517174690632163208997960994658032931771369670*I,
   4.43764445863462357087791264041203991070230592514185767615-
   0.97936447138369505306219693236395975676934388454409244395*I,
   3.72409493829222671743311721961541926548310776312968209574-
   1.35096977828464083841733464429708765826853003985793539464*I,
   3.09850710522521671435540631959674231971376608562873653741-
   0.80907289828137160632816596110237083478759930980885443851*I,
   3.14061257770928088101723385470518177037365445282151309514+
   0.59132285565907565907491440476487196775804275872314295070*I,
   1.52136576333063718386710276867017801996941781276612485985-
   0.55501366399231677126815322786328733813992085194611238345*I,
   -0.5781434243830668847547669568620259846019203051953201655+
   1.82679964221112554691669760661890139937361685540635144595*I,
   2.49914930074864692110378794293433308712427994349118527606-
   5.32558912949184455359954679060082549156259130097151631750*I,
   0.97520080579873252791467909718934042649905434484216828237-
   1.84847843785274974668269826590106864803833946523938250691*I,
   1.72496916984837426025364244531728367870257345561536962440+
   0.75366282910291939449102062831652367264246265217819933084*I,
   2.92262866135883755489894373842111982891242731228003942070+
   1.75365195585787085618031359989822240009023933623746389138*I,
   4.23699607142871236571598466024481341321051035618026332341+
   0.99528546044850709881355898503765838804978617327346774786*I,
   4.76386725923362185393748522174707303734384149522490799505+
   2.73854838051110601948690687719203680378849974476038427748*I,
   2.69955501091971934615799110454143219068764293270404327668-
   3.05151113666475779268457533983163464628045976438128380645*I,
   3.55473577573011223629563365191052799596452820391758278364+
   1.32009743274388595682167793802301998712310799670537779061*I,
   1.08213048134604109383518367427505402456134242159061856909-
   2.42521167349994215900979815381323400961693607760645244016*I,
   1.56748288028753001820810282846510229888432453767638515527-
   0.10267924584672631997094427290004680269004944959842685131*I,
   0.59334440499048775072605540160965441823389702798774316828+
   2.18173921225043272186567116458428193893811524450076279104*I,
   4.95476387257415888237951148394944754952403430913431550851+
   4.54098669081530990355410538874120233995499760560502474532*I,
   3.45783697675322198767349841665726133620963956096643134218-
   4.63590514139401049402078756296961971316242624301521014598*I,
   1.98069754919870222621405841382620264480621832758419670775-
   2.04537278584618099195258441451360624335689953756414707054*I,
   2.42613958724465114329009693774349539313745096738019286066+
   0.32426567404913392335565874325929089937667294879887693925*I,
   3.04154033520534155742094925017961649341960453302191674524+
   1.74452713604076013700498572414316388260159573889135565144*I,
   3.93994879271599094274198955189818551188533092037386247965-
   0.34916315502963656563245087181274464212792160210480493808*I,
   3.61406031459208594836799352021837974977208789817099776638+
   1.76964465164541649856843267737804803417346967003643844238*I,
   5.27249601651395829441717000401715909240861741107306847735+
   3.49596033353431210690810045178537638645025624531141889512*I,
   -0.2726342850027964245922203837659640697764630944868676299-
   2.31987685840053893635013213823967893509638866562559716817*I,
   1.84211733533571103124704133953490923433346832652208609951+
   0.40159730146222651711370898691549399233008663517809304023*I,
   2.32016300018930483322270320528351776133061200650437422147-
   0.68175058950408806877263856887306643998307337621309144651*I,
   1.80576195769822164829255896562357553569149008355873245845+
   1.73925160925642447290712281250496822439097788102674293301*I,
   1.99348555951639944851891653380626256933039229300704125270+
   4.85578814100578300039440281603356166592757208113081055861*I,
   1.65676781642752097099882578738060844943674372479221792913-
   4.29029005973502196502151754475567173895723284434825115250*I,
   3.09841077548707686952010903588810951354300915411017480151-
   0.54947036511883829985738189382068707307631660214094433650*I,
   3.68090342682666208794189192630226083382670022398808304662+
   0.24499985580754977121051539662396947637453376353361110141*I,
   3.72959872076908987587685792842627927915448559630198855606-
   0.63639115672840859414582002496665947855335384641708819462*I,
   1.65337656701109316195212661056089581655425081375663549060-
   0.86133322485685644407846176461642890970994857909465280050*I,
   0.30210198139362625329442598160033255739419421844027084359+
   2.10300771966525564392951991677659726421079842784443049495*I,
   7.01098995498244041839615763356850005890026283453157802654+
   2.34298131182955333991631631088405257681844961377384900412*I,
   4.02081822970498790183152144627399980651863798408140413472-
   4.29620681523380724298551244184436021027654752844509215968*I,
   0.92670310329510956991043217815101278733497871989167019271-
   2.07443775721552739109794689418418358343170490317772205908*I,
   1.53352203813173490042145150777786743915838380297058366832+
   0.08545094096507020564103495264232801241042741483575716189*I,
   0.60207219181990857788018211545916706609531876043019946392+
   2.40758618165404202616527205373200469818143292182833519642*I,
   5.19880093859217025345818000521310662963378837661796334790-
   0.27743208612816013789790297772156334458006085351900211142*I,
   5.10022159154580728245213708956187809724175050432178517098+
   2.26498328727295937428042326188732335139998577884763548156*I,
   3.03890828784703841711726634005190829113966541458332023720-
   3.21937956332106758800377103491759546767166546155906316320*I,
   3.76713099346812303052506168277960838511581452389186243967+
   0.33427375541301575284650424157004274132238739279377869529*I,
   2.80184354273917402799247125256942453520313610287403432816-
   1.86307261284465240885875851027760608965933788403917014100*I,
   2.64651617904317713956924796747811559989488170852532546015+
   0.06832195887883674832174863094427470346573170461596703316*I,
   2.38380445872865431485470853476727393685001160539224181440+
   0.84064614800671665945345499322708577202760360934201300069*I,
   -0.1277172037513452704669327356918693928179183125936513316+
   4.02254467917248851655134328478898481184987385490349529059*I,
   0.23645488445405368161340963685451498233621730879756403997-
   4.51086880110639785884499443776543295598779603354669755600*I,
   2.04061147827878168589801599387210956537858951986973803371-
   1.27043704348103484342090484733580221111309491491429567342*I,
   2.53849114198044277559735540797852273714191061517855689981+
   1.00558828465193983852495669675058005505178609411651102839*I,
   3.02331994931724385669239288639083830837423528731772805159-
   0.45183595756789202180913270411162430887349441432832394333*I,
   2.36922934264715902086556396613825292111297730977158740243+
   2.65233486684983635946918905033911823708656819356870249964*I,
   5.18495438085891888344696240938256930750462084721887360640-
   0.23703289302908468082821618425098567775355895635933451659*I,
   5.23008742755303718557205255642964380054258359478004236957+
   1.65466278650313730541188998542164404189517114480644304161*I,
   5.79626066011783108573999431791491764148593363372851370594-
   2.02893062427057687109434860712310896316527069931075934393*I,
   0.40053132998569555011004200454450777148715094127642314895-
   1.99269983773667081904881436149447134747199936652537506947*I,
   1.55913700485710592492978691882803948628583907285376428502+
   0.59567015160347300975449620781776651261026081342104353982*I,
   2.44927658876324127854412664795943159059193247082485800531+
   1.17867932093994054449396454042787645971072722617968130810*I,
   1.37738198715056937487326895214218479665759626465316709821+
   4.16036804903646118203850801865451082260092900351464747203*I,
   7.36604737501065353794641033602532502899068790915640763480-
   2.35392137650098705024463730686321673625979700757621153173*I,
   2.48238287237925708470609924411446758171479871554742003320-
   3.46334837303570247701058171200645043473796218935781594674*I,
   1.57511580989946358517525553084522264952813797253797868118-
   1.18079885886247097964520552320684179016353688516784804205*I,
   1.19190600099979994712350424215175132133730167465768470923+
   1.97056265975069805410976827994503367044539445670502643552*I,
   2.39700655755573788041409347353929034234088337666994463674-
   2.03928615518998879719688016856854395161682074115687216282*I,
   2.24941481435620705150676389457199672142873937483882407764+
   1.02831427455792620106759386111620160488581050925076668432*I,
   1.33174331152628218611226941998484921924620476400027119296+
   4.27429441213133937982593166834041973708477321977988527714*I,
   5.19163896300814618817044029796107755627265942088676949600-
   4.55862612886783141752745360982952435346710520280518168424*I,
   2.71470734148940558969119657158734459396112560673708530689-
   2.77026313451706532496628084113407051550944262709205732716*I,
   2.11398183732076751127852900951752057431883255796363575556-
   1.17853870898179689957084660629050105623887653404730553340*I,
   2.05806732629045476528558273907645101204388373302951877481+
   0.63392500643022003035445088536425720238815192769532504429*I,
   1.43210991060149365885922380408689895736367354992375775017+
   3.10085609061320371235598277296989026955261897770431304744*I,
   6.74746650405878365341157193025313771798558789106941512546+
   2.77032367106692354166923602834257238489135207523408130576*I,
   1.10942751932177999158746179149756388243525047698572321127-
   3.02148398023354333197488981371466544378392716424500032710*I,
   2.54852933258342317843026792588884837594628126070923282412+
   1.39501272035751252194399864649658099881936164293129121688*I,
   3.83648833705851227081893602618387988436508006234383762050-
   2.04439784052283449264569974946765997406088692540450172430*I,
   2.32401586749889040235155503845435223015985881664598552048-
   1.21577724628470208816542002690100834603837891659763213817*I,
   2.19937996044055692984141494408740892835472951677201641581+
   1.50820676882557145749416486794851817529204173871868464715*I,
   3.58390648261679254530121010815804506827024008788012233173+
   1.59029442565931908839614337519314358751465363155219370457*I,
   2.82055695260176004105100909713931481740601276280006923774+
   5.38625602880726683406119262555538440584585953329991327865*I,
   -0.9619670157803240726586566129620161856835108093997484095-
   1.95613513204062933418480397767253624978851519420716806115*I,
   1.63863185273519501588934445867603564815853605045409355133+
   0.00029073484115064860638330671669622821956588979519418891*I,
   2.52301992282179951830943812869322031544972215031565391087+
   0.09699290230474564877763493858835105776198361587015495405*I,
   2.29090432223561746659084073216388064926879572338231995604+
   2.49289438749551814030361272695769512985291964023384939902*I,
   4.47572626530262169269734578616110362017428983131529319884-
   0.32512433737473133799040799425601391690757608251084587547*I,
   4.03446673796063155568248094631779942929875090552095341184+
   3.03830199227088101609764444817628241163044395545046298889*I,
   5.59663633990061303076842626722594234225533191265959503006-
   2.37002705950187904103767936016391261251674922268068956437*I,
   4.26400430816542920719705856988922388751465910737843484178-
   1.72265808566590755253790120870772783917197940047044255539*I,
   3.92295890949190946106223436811891956369748942578242204227-
   1.06582048135515667541551555454391874281828023349409859476*I,
   0.54628926946631724653549304690405904286195782572031427672-
   1.06458803192433616579165928674934224648228374370587045713*I,
   0.49663883627353214036063167760680364867408456706123119433+
   1.00905328415347152554154637634246790371188742396154591478*I,
   0.11254271939248227725813163446389063153913899262417180439+
   4.47842607715879021363792492734427442699093166686744491560*I,
   4.70790157685396227652518389484337380016564558901406314648-
   5.19419914236541424718963196841871347283879030620884539709*I,
   3.40999048230547838189401573294213933455203193576595728637-
   2.44796395885482612150257995524018627193358446065017105478*I,
   2.26772246145514552304789336074462190718214335971972467914-
   1.38690249407336269440475521830385581893304556396989035485*I,
   2.40110004548193662264037671125936435425642167078389444767+
   1.42663517566915629553300301419852585469512299405412104913*I,
   4.16707739862172983079455311811155650277400026478429055709+
   0.74981515571585633698404409776153815090222448755460954688*I,
   3.89034029359696148121066168057777200989130733440500712924+
   0.10467992809880096565087928020523599966489046811347845667*I,
   3.44589058076429212933543254182745553631800628792981733045+
   3.23013234022635293294377561657596518788573339883674688034*I,
   7.64020112705589144041667221088329388363357775431192153398+
   0.41674823524593026956423017763005279757512401452725069240*I,
   0.84678715843393701004363627528644335844280417787747499200-
   3.68971701640826853288087400488082700185671403318525996206*I,
   1.24821439644346771584617878683093938832384191400132785419-
   1.02236612711048514385120944803094220427960077697220521729*I,
   1.05578273741777637518446403012146270365926251323970489953+
   1.51974254227662685471931728968938906520505694755185457257*I,
   3.43595301287001138146502959954818742953892743856159569359+
   0.60863793754809205547083481839787147355942836175022349465*I,
   1.53718536177372689968880844141233571937538626528036259302+
   4.49675849355596969398777071236008582287497933907058181471*I,
   4.60124756655642379020116976776141683624180395485960326426-
   4.97863478639691530969088250237887932472481036801161185115*I,
   0.39882012272386308208623393833601117269907756738435716205-
   1.35111891243929948320810640284428962331298472139909815435*I,
   0.67563115990324390986252512098325532504936199822590566044+
   1.26901245393141243207376886688203266355958579866384132939*I,
   2.71852037568216317373013367777422496542178071445738309313-
   2.33904951637075418418230382996806989300413113537360872890*I,
   2.68663899314590902833080059429252205678016304258730476221+
   0.28428886014897127541656680462978142155189476403270886120*I,
   2.72387066384295892530730275216865884786870664517214961501+
   1.71418106576338001456485645946275869673202122216704293383*I,
   2.22250842748787061364519366130027855454727520433145985849+
   5.14900140913477230083401333776356880664420124055434814346*I,
   3.17632864243615252708863322095273023575508525956043076838-
   5.37180700125847338613802142216024000311875467517064563698*I,
   3.17274840854106340043855564607939804724535082850837779493-
   2.12849794059188830139062809844026977342230222857379091948*I,
   1.35847447434839103132884171390896839395595380331187471435-
   1.36843478092526219879814524032264062098760207224482776256*I,
   1.36537002183468450894006901842711399675436162045267636359+
   1.25000728927322915733624215869237286645268386426033920346*I,
   1.95760462885444533835733733124975124583624216518676196824+
   3.84411470534861673785108582337187708885186991510778461929*I,
   4.93095781644499144207650687808668117478131447312050685030-
   2.17674864080448816555542019723609267472238690349442206967*I,
   4.82129683595912149608796056441381559085209956811105174371+
   1.91106766934514327953739429297187859278000937851107428092*I,
   4.46333345095087357866574379695302387898309592438189850405-
   2.90541045600229518090612100941515643973184934173533698885*I,
   3.69525474935519260998157685843648818137571211747546266504-
   1.37381424231687786312288710654696095941324897535245580781*I,
   3.34985362209816544122815529064766008409981422511652463950-
   0.74241485148893244625789103645625289041077921591352542122*I,
   2.13870980555162406206755390128641273195362550549008997195-
   0.66690071999273419754488703403015511783360414131169308147*I,
   1.09723230972983625137811070468515775319611308448571367149+
   2.26500018298542782417334744046348543922005919047454712226*I,
   3.18321027239425875215572332054305546399693750485421557363+
   6.12938088111389582537200398864403757519656874036093470668*I,
   0.40145060547357628239820544335437791759612034778187210489-
   4.97152792798064475470384479597018161215668470599428736196*I,
   1.63233849871571456460940680037021114477838589098843070855-
   1.58123249394112454460554439332747957312672285887811191429*I,
   2.13157237030452577468311436089814766946012304366904679634+
   1.03052104771738102421548139488969393328859087755060847413*I,
   3.77244508314384640041428849350548694448107918260618327871+
   1.59870694156835350028197005826724942472301788147366742465*I,
   2.48910099026378640596863445087308038903221259031676467537-
   1.19323869133171238027082797123730188085041666467804007705*I,
   0.97679385129246734690625354765211107809597118524507009009+
   2.94021926690811187623854098211984779918386512772504051963*I,
   5.13276591230267889722919754286015291615114394092330704722-
   2.54223171709497215689742333574191488670648197212535080564*I,
   5.35813594841251981373985038347227692427983751469405142104+
   1.55952375075822495815860893090727351447952279703433618622*I};


(**************************************************************************)
(*                         RiemannExpIntegral[z]                          *)
(**************************************************************************)

REIConstantA=0.2837571104739336567684576306353281403


OriginalArcTan[z_]:=
  ArcTan[z]/;(Re[z]>0 || (Re[z]<=0 && -1<Im[z]<1))
    
OriginalArcTan[z_]:=
  ArcTan[z]+Pi/;(Re[z]<=0 && (Im[z]>=1 || Im[z]<=-1))


RiemannExpIntegral[z_]:=
  Module[{s=0,so=1,prec=Precision[z],
  z2=-(z/Pi)^2,k1=1,zf},zf=-z/(Pi^2);
    While[so!=s,so=s;
    s+=N[Zeta[2 k1] zf/(2 k1-1),prec];
    zf*=z2;k1++];s]+Log[z]/2+1/(2 z)-REIConstantA/;
    (Abs[z]<1 && Re[z]>0 && Precision[z]<Infinity)

RiemannExpIntegral[z_]:=
  Module[{s=0,so=1,prec=Precision[z],k2=2},
    While[so!=s,so=s;
    s+=N[ExpIntegralE[1,k2 z],prec];k2+=2];s]/;
    (Abs[z]>=1 && Re[z]>0 && Precision[z]<Infinity)

RiemannExpIntegral[z_]:=
  Module[{s=0,so=1,prec=Precision[z],k1=1},
    While[Chop[so-s,10^-5]=!=0,so=s;
    s+=N[-OriginalArcTan[z/(k1 Pi)]/(k1 Pi),prec];
    k1++];s]+Log[z]/2+1/(2 z)-REIConstantA/;
    (Re[z]<=0 && Precision[z]<Infinity)


(**************************************************************************)
(*                         RiemannLogIntegral[z]                          *)
(**************************************************************************)

RiemannLogIntegral[z_]:=
  RiemannExpIntegral[Log[z]]/;(Precision[z]<Infinity)
  

(**************************************************************************)
(*                         ZetaNonTrivialZeroList                         *)
(**************************************************************************)

ZetaNonTrivialZeroList=
  {14.1347251417346937904572519835624702707842571156992431756855,
    21.0220396387715549926284795938969027773343405249027817546295,
    25.0108575801456887632137909925628218186595496725579966724965,
    30.4248761258595132103118975305840913201815600237154401809621,
    32.9350615877391896906623689640749034888127156035170390092800,
    37.5861781588256712572177634807053328214055973508307932183330,
    40.9187190121474951873981269146332543957261659627772795361613,
    43.3270732809149995194961221654068057826456683718368714468788,
    48.0051508811671597279424727494275160416868440011444251177753,
    49.7738324776723021819167846785637240577231782996766621007819,
    52.9703214777144606441472966088809900638250178888212247799007,
    56.4462476970633948043677594767061275527822644717166318454509,
    59.3470440026023530796536486749922190310987728064666696981224,
    60.8317785246098098442599018245240038029100904512191782571013,
    65.1125440480816066608750542531837050293481492951667224059665,
    67.0798105294941737144788288965222167701071449517455588741966,
    69.5464017111739792529268575265547384430124742096025101573245,
    72.0671576744819075825221079698261683904809066214566970866833,
    75.7046906990839331683269167620303459228119035306974003016477,
    77.1448400688748053726826648563046370157960324492344610417652,
    79.3373750202493679227635928771162281906132467431200308784387,
    82.9103808540860301831648374947706094975088805937821491465713,
    84.7354929805170501057353112068277414171066279342408187027355,
    87.4252746131252294065316678509192132521718864012690281864555,
    88.8091112076344654236823480795093783954448934098186750421998,
    92.4918992705584842962597252418106848787217940277306461750967,
    94.6513440405198869665979258152081539377280270156548520195924,
    95.8706342282453097587410292192467816952564612249879984205292,
    98.8311942181936922333244201386223278206580390634281961028193,
    101.317851005731391228785447940292308906332866384300894799928,
    103.725538040478339416398408108695280834481173069495764519885,
    105.446623052326094493670832414111808997282753928535138480569,
    107.168611184276407515123351963086191213476707881404765279264,
    111.029535543169674524656450309944350415345968390073056846190,
    111.874659176992637085612078716770594960311749873385873816619,
    114.320220915452712765890937276191079809917657723829892287728,
    116.226680320857554382160804312064755127329851232383220283862,
    118.790782865976217322979139702699824347306210592809382784193,
    121.370125002420645918945532970499922723001310631728742302575,
    122.946829293552588200817460330770016496214389873863517211950,
    124.256818554345767184732007966129924441573538774693561140355,
    127.516683879596495124279323766906076268088309881554982482799,
    129.578704199956050985768033906179973608640953264659431030470,
    131.087688530932656723566372461501349059203547502975045383139,
    133.497737202997586450130492042640607664974174943904675015102,
    134.756509753373871331326064157169736178396068613647164416976,
    138.116042054533443200191555190282447859835274624146235685344,
    139.736208952121388950450046523382460846790052565382603081370,
    141.123707404021123761940353818475355090300660879747620032104,
    143.111845807620632739405123868913929966233102430354632548598,
    146.000982486765518547402507596424682428975741233095803636976,
    147.422765342559602049521185010431506168772775250476830601010,
    150.053520420784880351432467236959370623037321559528200448429,
    150.925257612241466761852524678305627602426770472996717700311,
    153.024693811198896198256544255185446508590434904145506675199,
    156.112909294237867569750189310169194746535308500942920803856,
    157.597591817594059887530503158498765730723899519141733538249,
    158.849988171420498724174994775540271414335083049426966257724,
    161.188964137596027519437344129369554364915790327475466579188,
    163.030709687181987243311039000687994896964461416477683115209,
    165.537069187900418830038919354874797328367251745068604478953,
    167.184439978174513440957756246210378736460769242616767361106,
    169.094515415568821489505871181431834796667648580441625087382,
    169.911976479411698966699843595821792288394437125341373018541,
    173.411536519591552959846118649345595254156066063420117933682,
    174.754191523365725813378762455866917938755717620571663445611,
    176.441434297710418888892641057860933528118497108809715347612,
    178.377407776099977285830935414184426183132361461272503701489,
    179.916484020256996139340036612051237453687607553018406541300,
    182.207078484366461915407037226987798690797457778239908766630,
    184.874467848387508800960646617234258413351022911950667773178,
    185.598783677707471466527704268392646612934717649513283088919,
    187.228922583501851991641540586131243016810734603990319151464,
    189.416158656016937084852289099845324491357103023193354355419,
    192.026656360713786547283631425583430105839920297977096916289,
    193.079726603845704047402205794376054604020615810548860138504,
    195.265396679529235321463187814862250926905052452286924060110,
    196.876481840958316948622263914696207735746028691942215482823,
    198.015309676251912424919918702208867155062695438570996721534,
    201.264751943703788733016133427548173222402863639186734080632,
    202.493594514140534277686660637864315821020244899420053909069,
    204.189671803104554330716438386313685136534529228741907350959,
    205.394697202163286025212379390693090923722914772048407002134,
    207.906258887806209861501967907753644268659403768883999858657,
    209.576509716856259852835644289886752175390783181326162468977,
    211.690862595365307563907486730719294253394030982935643736210,
    213.347919359712666190639122021072608821897183276633069059853,
    214.547044783491423222944201072590691045599888053083076400081,
    216.169538508263700265869563354498128575453714274164110976376,
    219.067596349021378985677256590437241245149182927011351373557,
    220.714918839314003369115592633906339656761145077661965701611,
    221.430705554693338732097475119276077950222331077319909379419,
    224.007000254604335211728875528504895356085989949595529762950,
    224.983324669582287503782523680528656772090054485587426988477,
    227.421444279679291310461436160659639963969148321976628364893,
    229.337413305525348107760083306055740082752341387818517532636,
    231.250188700499164773806186770010372606708495843123371406806,
    231.987235253180248603771668539197862205419833994562496484726,
    233.693404178908300640704494732569788179537227754565836363014,
    236.524229665816205802475507955662978689529495212189123700918,
    237.769820480925204003236625926387107794160619352116061306831,
    239.555477573327628740268932034334492481708318326706162231351,
    241.049157796216586412837921410335670549645682844722093845319,
    242.823271934222600016826474458878549953940543767614932383169,
    244.070898497078158236816527989844501347100190716770327456869,
    247.136990074897499467550968179208132267864642009627181199015,
    248.101990060148459256762142084656997355810381258443319162194,
    249.573689644707209192329794188739970342611130682670739208899,
    251.014947795016001142954155103708048152326782831536646140653,
    253.069986747999477194599013785618090930087150249644973497918,
    255.306256454914022753086491794001423157910032814963418724098,
    256.380713694434477789358382339729530871216652390032749649553,
    258.610439491531368208983058644759131632194406284990085893350,
    259.874406989678000350672844613876592666198481464570218227224,
    260.805084504596870185931233472464548034938953872425499933459,
    263.573893904870132233081588131023303170314219436993895283972,
    265.557851838876320292477308964184914641004986152484753818972,
    266.614973781501072495720112973867911806635957187170113534128,
    267.921915082824059440378967172185618374292568143282723793016,
    269.970449023997602594693505318898479662926905288056308153801,
    271.494055641644999018179416757522850693543519562990489464633,
    273.459609188403287045714250298801772922840099677093524289078,
    275.587492649343841248740702619377784826447528597228431306284,
    276.452049503132938679887343638399241948079966680998861985207,
    278.250743529841954492748276711316258926117900655886740951903,
    279.229250927745189228409880451955359283492637405561293594727,
    282.465114765052096233027201186501024205506836280345817359336,
    283.211185733233867420493837943328938298455684878958633945245,
    284.835963980904724133157633922696216463142827928311918089613,
    286.667445363002884292847624146414939343868226282777807977480,
    287.911920501422187155254120271867510385461419440570658545109,
    289.579854929218834152738023569352343889669498362942550696531,
    291.846291329067395835513054424638511882820635599982135545691,
    293.558434139356285356776697106035077343798834356470953928312,
    294.965369619265542175066448639009671343055445882550616223446,
    295.573254878958292388460831458778610637285157110630222664388,
    297.979277061943415209929682957682834181057097189798912501870,
    299.840326053721312960027052525293769254215570064342983560988,
    301.649325462194183623470100208417982081105610093523294617292,
    302.696749589606917051751477095352922762935820411681497944170,
    304.864371340857297700148749903144499592586945838241946060389,
    305.728912602036809289222821261660967256963159579082375631563,
    307.219496128170054789410033399934502267433848278422839089705,
    310.109463146701898804786219767998945834763013181532886478376,
    311.165141530356003270942670800354819899188804939703868624465,
    312.427801180600891980485983092874263762853940093152918507952,
    313.985285731158922979048965754576328568024981575154166030099,
    315.475616089475733868596078143953765335774697630989644705975,
    317.734805942370180395645494204968114015242740585147951448459,
    318.853104256316597906689184547749182203013102410885384706861,
    321.160134309113578291921471417430694029752662798292274838201,
    322.144558672482932298837445005988549260371980208614465394803,
    323.466969557512050506212030414795163356763087177694561565630,
    324.862866051739613264980086995400409919804521051533191805781,
    327.443901261905457343469263816320703356694348255731951874570,
    329.033071680480934033614727576803946203692825604421436546685,
    329.953239728233866343892122188631466058323921638948957539131,
    331.474467582663424375661753866344827923217600313511902693449,
    333.645378524869850584961683080879425380867826435891801614520,
    334.211354833244383232403407959192493154187277022001420722086,
    336.841850428390684794654762919411886007208368560628434222040,
    338.339992850806611886257326087163203390917643563347098475936,
    339.858216725363540192326550930873997183197044249769493305426,
    341.042261111046560482597784598536917187337647470737227608585,
    342.054877510363585451403825094098056715186930665395485777544,
    344.661702940252337044181188098199185782715242402814928513287,
    346.347870566009947395936459816151933898196735443462899867733,
    347.272677584420484475797094888069979676080928456855573803225,
    349.316260870696144123155555733993721336088905562238856261694,
    350.408419349192099187671953234487234469645873664331022542127,
    351.878649025359280436713393076596932729930319669585437661895,
    353.488900488718806783603768609435318413343265129892633147378,
    356.017574977264947317960361960766442675714445547193873539435,
    357.151302252039624809602928232290356611757081185117945937496,
    357.952685101632273755128918982777442823466384714138303642399,
    359.743754953114448799291985976990295405373745761297431868072,
    361.289361695804650390291311227715228190875941637995833152511,
    363.331330578973834747334449566614731270035245758754729113389,
    364.736024114088993716262102126940400017202300305689966833307,
    366.212710288331316861077145196806574179109375379860613495223,
    367.993575481740303326183298044207846399024882018516545864502,
    368.968438095734389891576901299891910638194413780711011694661,
    370.050919212106000339651163061266611422466593933768732981525,
    373.061928372112838449119396431285391902941772742312801963711,
    373.864873910908569744756362733659460949678507922263611821346,
    375.825912766739334107907714146693025752929666674355203202167,
    376.324092230668052117190819612427579612962026684976087077565,
    378.436680249965479724090965913203520556316530938757842888303,
    379.872975346532346651024059690446271568109156968041856582558,
    381.484468617186524919662522423657395365799198385042587464169,
    383.443529449536487704345755480722536904199311056508956821600,
    384.956116814863687103751584208793513390270929150123542574060,
    385.861300845974229180561959359803257615611806561018259022433,
    387.222890222387980975948514738109814090964039296706784362239,
    388.846128354232254600809420300373558057355405857938161458595,
    391.456083563638045770578228122554134772225870114072316260537,
    392.245083339519096749015184170992880562362188445136741911064,
    393.427743844434025936698952920128869920492928920345546570343,
    395.582870010993720970877711323141642136070243910356783992411,
    396.381854222592186931999454491730529063761599688102123343517,
    397.918736209614243386981179710798683804483401291182062245902,
    399.985119876194899505917299868289645770638909961393128008937,
    401.839228600533216539911304378287230726400400393259495990124,
    402.861917763886114176315443096039634696894041477105245010900,
    404.236441800208004740227799563527690196140586752048083698308,
    405.134387459909927257486268025416736162756058477020315339041,
    407.581460386896182076309001181390537640506144974509680779263,
    408.947245502351112519634039764157901795622891749191114552029,
    410.513869193366638646769105284867187789692707298270351464060,
    411.972267804278750664640298507272917407539125085294282854674,
    413.262736070185046886257059317729090870648558511170895673473,
    415.018809755155115646319211462817221509881510703593663118525,
    415.455214996294598857128782486669824931693017207953958041990,
    418.387705789534779226045723099554798824172409177924694485207,
    419.861364818152323687852309138382817393330169016061582957548,
    420.643827625041786267974652985000480702457519021789136900249,
    422.076710058826759629840665449381375274245918175777902602002,
    423.716579627481818610562874731766074189262793520369936642457,
    425.069882494461347614374692649156431342104157303889429068567,
    427.208825084074580528142933885711598385191493806400507988912,
    428.127914076616682110305068486318159309260938775705959091114,
    430.328745430938636669926981541854862684153505293151286926601,
    431.301306930703592019505121927555681053518826916120718444216,
    432.138641734588568306253249108952716905139488335003735060420,
    433.889218480927225302946611050792902448876224624160672227014,
    436.161006432646984071801518262378037989871251163409139717018,
    437.581698167668581154013167233325459498790141788327466255382,
    438.621738656272196290915010137170395629783098112331954279263,
    439.918442214370656410221790027024039280832816189529305241693,
    441.683199201189023874204436499167993071419323647024442285169,
    442.904546302609449469723102412766202066087136266131509540147,
    444.319336277559155920305743539790620945587317644652268496570,
    446.860622696429522528860875180746743137681648820646181780887,
    447.441704194493290065526925303609159730480696368875211372840,
    449.148545685023304753023503134704650003335745648059295657162,
    450.126945780313524030045762528781705514390765396844599880108,
    451.403308445388795462113224631358811204209973747860455823829,
    453.986737806677916038366810294004858372241210971229888738984,
    454.974683768616788875309438951270945926994901297298634457627,
    456.328426689246051224499830063055483498457485318166013276206,
    457.903893064102971574699329171787645044895212306953809715578,
    459.513415281106011754009943802041405383613308852731605583679,
    460.087944422175841255330255428206546245523553777869013658976,
    462.065367274882530963830921145618462043227817554001640359480,
    464.057286910548284576246084783666675915832683288407258498496,
    465.671539211371094552966645743995528851494762058541572493821,
    466.570286930826255167392125952264412091020284178938806944419,
    467.439046210261638856645001384446842320172524711642123157542,
    469.536004559112032191819068829123165678003435566259150908102,
    470.773655478101647690118879454436353540928850509100551081755,
    472.799174661908816658297992681770003196973059754811364604700,
    473.835232345139687073805468023383043690661598855026696050332,
    475.600339369375785605428819923679925062405518812257956781852,
    476.769015237484520852848689195468311920887614784338868635258,
    478.075263766670969199872727404909514319880428804879150139421,
    478.942181534634826538317101767038484021904243109601895531744,
    481.830339376286561366681376285097598090203003919340697512179,
    482.834782790982397306556996676321646468696744168777107947021,
    483.851427212482537560188221084668127688889586966536701719214,
    485.539148129356006930025423658082117260806471749763154360976,
    486.528718261651244352367526269941499436227923522305402169082,
    488.380567090017448527111430664811922191767188460417426323978,
    489.661761577956131512780904174977104974169272683919510884359,
    491.398821593663006569213331008539128017633847524729896641294,
    493.314441581785300936360604043227082234686759172573355233194,
    493.957997805369464909583091286885151985412467988377523379936,
    495.358828822131277496834132737170598262641247397976652570647,
    496.429696215759103483918912816073020436220011011346345166502,
    498.580782429686542016675082912487905161561476333053766656623,
    500.309084941690495539309390725171446472704870369647770876182,
    501.604446965145477663332545762851174533419386550991444638303,
    502.276270327118233175399507333885342548651707838851562078936,
    504.499773313427737183791262228361389155148817066918955488278,
    505.415231742244442029552166109282855338114496513046725944221,
    506.464152709523531221526074780645230739269626692331544828962,
    508.800700336467820809469672508191999337705587997163507295654,
    510.264227943672834420779517654734925130171257929297557722395,
    511.562289700374595460454904486599125570312683709013315643808,
    512.623144531407418667101254943481034069611131681544228641452,
    513.668985555473683436244146417926108827951893210124015418476,
    515.435057167299377249676893672957310708188070759439040867082,
    517.589668572467425341357965286940548832792058007046841015537,
    518.234223147550143573858274373479820669062436287412602273081,
    520.106310411723255903196146134261858075622441724293615075751,
    521.525193449492040967732398163194141203786999138040744488178,
    522.456696177730210430144413322512508137587977933878769399996,
    523.960530892015840487007509480972102533964237228112711626327,
    525.077385687279622180591217630138044888849347484163783800971,
    527.903641601272345229617268071154120425858445483088705287296,
    528.406213852292658941608896647383642662683157410699345194441,
    529.806226318706900798163983301564829357041689242415750759989,
    530.866917883961089644387434514856070176110764240543701164705,
    532.688183028293730505126445569143568476310285988671403254081,
    533.779630753768732565482546023135472721918119360259666542753,
    535.664314075873224617046123182274714681444498945062783584708,
    537.069759083122327588389737753582268038726636386780733694983,
    538.428526176247962843500955239781566770638701359261144594385,
    540.213166376228133383645668989963350953024035181900009742267,
    540.631390247295117360128077599175934027048048454650868342065,
    541.847437121201281547119113508906736693415121753136291881514,
    544.323890101005262903121308755760836204503042278881158455527,
    545.636833248934818254855439794422051566830332135202656375359,
    547.010912058122292463655881793125071664259503914834657472295,
    547.931613364489338310451159426145557525438785686258318549292,
    549.497567562661378459984733879773569963624316558198385971984,
    550.970010039483889045657234056993886473630308383897687282667,
    552.049572200564892792576702545569569680427366907946193306100,
    553.764972119158814617149782592093555711203694252599487181091,
    555.792020561682508416573221485355189326697569200784319039644,
    556.899476406855351261964218656146374472616320615719862820677,
    557.564659172058528408523989874331277788818355032438094666486,
    559.316237028682163760935142240205788971567546227973498991616,
    560.240807497295668241793276358860519826586176918269635720233,
    562.559207616045851108137916695324536239641021958784522127835,
    564.160879110786117813879533500406528663935670739735878856857,
    564.506055938149835122245968938976840576910146090502594447789,
    566.698787682807956241512280667240726318436084182938348106232,
    567.731757901176937450334730493575064641799409895436366627343,
    568.923955179629368496753487416866151730569267205845121387045,
    570.051114782463592038527016601327868840511622802852389581741,
    572.419984132452764045276927107346862149490447255676494994195,
    573.614610526758129987246032109643300937226895595346026408380,
    575.093886014494885607457172282198207852584241612813236654068,
    575.807247140928780709429332894430443853037021115963657248319,
    577.039003472098211216637089687739189296759367579245255949638,
    579.098834672036607431284364328921100148033526056936214247269,
    580.136959362384628672716276348033200009168512453105408424071,
    581.946576265901625551506114544723956732510563126586377160909,
    583.236088219167278261960573649485662097389626069575466706680,
    584.561705903465528366945893393454466849226298874506683099985,
    585.984563204988300574187258985588990838294060300518842532681,
    586.742771891250155644771845087345220874712065065123879652185,
    588.139663266247956417554235270490785291465779184145835628073,
    590.660397516765275631032003310274274860778016912222030125030,
    591.725858065048056649222446472740558131004620037277461144193,
    592.571358300225569820772716120316474304065122812542448119991,
    593.974714682231029243805174509381626220203313046928788951633,
    595.728153697388949177020920732867804422663544399957321454534,
    596.362768328393684089579097070462356203840902612662315983192,
    598.493077346164754401063582936110050837384035079309115335893,
    599.545640364364853997515395144445410292207207969226645194189};


(**************************************************************************)
(*                     RiemannTermNonTrivialZero[n,z]                     *)
(**************************************************************************)

NonTrivialZero[n_Integer?Positive]:=
  1/2+Take[ZetaNonTrivialZeroList,n] I

RiemannTermNonTrivialZero[n_Integer?Positive,z_]:=
  Apply[Plus,2 Re[ExpIntegralEi[z NonTrivialZero[n]]]]


(**************************************************************************)
(*                       RiemannVonMangoldtPi[n,z]                        *)
(**************************************************************************)

list=Table[N[MoebiusMu[n]/n],{n,341}]

MoebiusIndices=Select[Range[341],(list[[#]] != 0)&]

MoebiusData=list[[MoebiusIndices]]

RiemannVonMangoldtPi[n_Integer?Positive,z_]:=
  Apply[Plus,MoebiusData.
  (RiemannExpIntegral[Log[z]/MoebiusIndices]-Log[2]-
  RiemannTermNonTrivialZero[n,Log[z]/MoebiusIndices])]+
  RiemannPrimeR[z]

RiemannVonMangoldtPi[0,z_]:=
  Apply[Plus,MoebiusData.
  (RiemannExpIntegral[Log[z]/MoebiusIndices]-Log[2])]+
  RiemannPrimeR[z]


(*****************************************************************************)

End[]

Protect[RiemannXi, DirichletChi, DirichletL, 
        PeriodicZetaF, HurwitzZeta, ZetaPrime, 
        StieltjesFGamma, SitaramachandraraoDelta, 
        BellExponentB, BellExponentB2, GlaisherRamanujanG, 
        GlaisherRamanujanG2, LandauHurwitzP, 
        RamanujanSiegelTheta, RamanujanSiegelZ, 
        FibonacciZeta, 
        RiemannPrimeR, RiemannPrimeRExp, 
        RiemannExpIntegral, RiemannLogIntegral, 
        RiemannTermNonTrivialZero, 
        RiemannVonMangoldtPi]

EndPackage[]
